/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qinputdialog.sip"
#include <qinputdialog.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qlineedit.sip"
#include <qlineedit.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qinputdialog.sip"
#include <qinputdialog.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 60 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 482 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 63 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 425 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 66 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 460 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 69 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 438 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 72 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 363 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 75 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qscreen.sip"
#include <qscreen.h>
#line 78 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 81 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 84 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 87 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 90 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qwindow.sip"
#include <qwindow.h>
#line 93 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 96 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 99 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmargins.sip"
#include <qmargins.h>
#line 102 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 105 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 108 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicsproxywidget.sip"
#include <qgraphicsproxywidget.h>
#line 111 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 195 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 114 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 117 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 120 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 123 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 126 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 129 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qfontinfo.sip"
#include <qfontinfo.h>
#line 132 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 135 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 138 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 141 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 509 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 144 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 471 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 147 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 570 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 150 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 619 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 153 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 592 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 156 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 608 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 159 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 675 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 162 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 302 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 165 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 412 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 168 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 398 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 171 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 384 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 174 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 253 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 177 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 205 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 180 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 52 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 183 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 186 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qaction.sip"
#include <qaction.h>
#line 189 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qlayout.sip"
#include <qlayout.h>
#line 192 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qsizepolicy.sip"
#include <qsizepolicy.h>
#line 195 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 198 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qkeysequence.sip"
#include <qkeysequence.h>
#line 201 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qcursor.sip"
#include <qcursor.h>
#line 204 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qbitmap.sip"
#include <qbitmap.h>
#line 207 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpalette.sip"
#include <qpalette.h>
#line 210 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qstyle.sip"
#include <qstyle.h>
#line 213 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 218 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 221 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 224 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 227 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 230 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 233 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 236 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 239 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 242 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 245 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 248 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"


class sipQInputDialog : public ::QInputDialog
{
public:
    sipQInputDialog(::QWidget*, ::Qt::WindowFlags);
    virtual ~sipQInputDialog();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void initPainter(::QPainter*) const SIP_OVERRIDE;
    ::QPainter* sharedPainter() const SIP_OVERRIDE;
    bool nativeEvent(const ::QByteArray&, void*, long*) SIP_OVERRIDE;
    bool hasHeightForWidth() const SIP_OVERRIDE;
    bool focusNextPrevChild(bool) SIP_OVERRIDE;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery) const SIP_OVERRIDE;
    void inputMethodEvent(::QInputMethodEvent*) SIP_OVERRIDE;
    void changeEvent(::QEvent*) SIP_OVERRIDE;
    void hideEvent(::QHideEvent*) SIP_OVERRIDE;
    void showEvent(::QShowEvent*) SIP_OVERRIDE;
    void dropEvent(::QDropEvent*) SIP_OVERRIDE;
    void dragLeaveEvent(::QDragLeaveEvent*) SIP_OVERRIDE;
    void dragMoveEvent(::QDragMoveEvent*) SIP_OVERRIDE;
    void dragEnterEvent(::QDragEnterEvent*) SIP_OVERRIDE;
    void actionEvent(::QActionEvent*) SIP_OVERRIDE;
    void tabletEvent(::QTabletEvent*) SIP_OVERRIDE;
    void contextMenuEvent(::QContextMenuEvent*) SIP_OVERRIDE;
    void closeEvent(::QCloseEvent*) SIP_OVERRIDE;
    void resizeEvent(::QResizeEvent*) SIP_OVERRIDE;
    void moveEvent(::QMoveEvent*) SIP_OVERRIDE;
    void paintEvent(::QPaintEvent*) SIP_OVERRIDE;
    void leaveEvent(::QEvent*) SIP_OVERRIDE;
    void enterEvent(::QEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*) SIP_OVERRIDE;
    int heightForWidth(int) const SIP_OVERRIDE;
    ::QSize minimumSizeHint() const SIP_OVERRIDE;
    ::QSize sizeHint() const SIP_OVERRIDE;
    void setVisible(bool) SIP_OVERRIDE;
    int devType() const SIP_OVERRIDE;
    ::QPaintEngine* paintEngine() const SIP_OVERRIDE;
    int metric(::QPaintDevice::PaintDeviceMetric) const SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    int exec() SIP_OVERRIDE;
    void done(int) SIP_OVERRIDE;
    void accept() SIP_OVERRIDE;
    void reject() SIP_OVERRIDE;
    void open() SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQInputDialog(const sipQInputDialog &);
    sipQInputDialog &operator = (const sipQInputDialog &);

    char sipPyMethods[51];
};

sipQInputDialog::sipQInputDialog(::QWidget*a0, ::Qt::WindowFlags a1): ::QInputDialog(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQInputDialog::~sipQInputDialog()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQInputDialog::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWidgets_qt_metaobject(sipPySelf, sipType_QInputDialog);

    return ::QInputDialog::metaObject();
}

int sipQInputDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QInputDialog::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWidgets_qt_metacall(sipPySelf, sipType_QInputDialog, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQInputDialog::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWidgets_qt_metacast(sipPySelf, sipType_QInputDialog, _clname, &sipCpp) ? sipCpp : ::QInputDialog::qt_metacast(_clname));
}

void sipQInputDialog::initPainter(::QPainter*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_initPainter);

    if (!sipMeth)
    {
        ::QInputDialog::initPainter(a0);
        return;
    }

    extern void sipVH_QtWidgets_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*);

    sipVH_QtWidgets_35(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPainter* sipQInputDialog::sharedPainter() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sharedPainter);

    if (!sipMeth)
        return ::QInputDialog::sharedPainter();

    extern ::QPainter* sipVH_QtWidgets_34(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_34(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQInputDialog::nativeEvent(const ::QByteArray& a0, void*a1, long*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_nativeEvent);

    if (!sipMeth)
        return ::QInputDialog::nativeEvent(a0, a1, a2);

    extern bool sipVH_QtWidgets_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QByteArray&, void*, long*);

    return sipVH_QtWidgets_33(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

bool sipQInputDialog::hasHeightForWidth() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[3]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_hasHeightForWidth);

    if (!sipMeth)
        return ::QInputDialog::hasHeightForWidth();

    extern bool sipVH_QtWidgets_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_32(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQInputDialog::focusNextPrevChild(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_focusNextPrevChild);

    if (!sipMeth)
        return ::QInputDialog::focusNextPrevChild(a0);

    extern bool sipVH_QtWidgets_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    return sipVH_QtWidgets_31(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QVariant sipQInputDialog::inputMethodQuery(::Qt::InputMethodQuery a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[5]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_inputMethodQuery);

    if (!sipMeth)
        return ::QInputDialog::inputMethodQuery(a0);

    extern ::QVariant sipVH_QtWidgets_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt::InputMethodQuery);

    return sipVH_QtWidgets_30(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDialog::inputMethodEvent(::QInputMethodEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_inputMethodEvent);

    if (!sipMeth)
    {
        ::QInputDialog::inputMethodEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QInputMethodEvent*);

    sipVH_QtWidgets_29(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDialog::changeEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_changeEvent);

    if (!sipMeth)
    {
        ::QInputDialog::changeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDialog::hideEvent(::QHideEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_hideEvent);

    if (!sipMeth)
    {
        ::QInputDialog::hideEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QHideEvent*);

    sipVH_QtWidgets_28(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDialog::showEvent(::QShowEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_showEvent);

    if (!sipMeth)
    {
        ::QInputDialog::showEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QShowEvent*);

    sipVH_QtWidgets_27(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDialog::dropEvent(::QDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_dropEvent);

    if (!sipMeth)
    {
        ::QInputDialog::dropEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDropEvent*);

    sipVH_QtWidgets_26(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDialog::dragLeaveEvent(::QDragLeaveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_dragLeaveEvent);

    if (!sipMeth)
    {
        ::QInputDialog::dragLeaveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragLeaveEvent*);

    sipVH_QtWidgets_25(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDialog::dragMoveEvent(::QDragMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_dragMoveEvent);

    if (!sipMeth)
    {
        ::QInputDialog::dragMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragMoveEvent*);

    sipVH_QtWidgets_24(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDialog::dragEnterEvent(::QDragEnterEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[13], &sipPySelf, SIP_NULLPTR, sipName_dragEnterEvent);

    if (!sipMeth)
    {
        ::QInputDialog::dragEnterEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragEnterEvent*);

    sipVH_QtWidgets_23(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDialog::actionEvent(::QActionEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_actionEvent);

    if (!sipMeth)
    {
        ::QInputDialog::actionEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QActionEvent*);

    sipVH_QtWidgets_22(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDialog::tabletEvent(::QTabletEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_tabletEvent);

    if (!sipMeth)
    {
        ::QInputDialog::tabletEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTabletEvent*);

    sipVH_QtWidgets_21(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDialog::contextMenuEvent(::QContextMenuEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_contextMenuEvent);

    if (!sipMeth)
    {
        ::QInputDialog::contextMenuEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QContextMenuEvent*);

    sipVH_QtWidgets_20(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDialog::closeEvent(::QCloseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_closeEvent);

    if (!sipMeth)
    {
        ::QInputDialog::closeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCloseEvent*);

    sipVH_QtWidgets_19(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDialog::resizeEvent(::QResizeEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_resizeEvent);

    if (!sipMeth)
    {
        ::QInputDialog::resizeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QResizeEvent*);

    sipVH_QtWidgets_18(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDialog::moveEvent(::QMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[19], &sipPySelf, SIP_NULLPTR, sipName_moveEvent);

    if (!sipMeth)
    {
        ::QInputDialog::moveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMoveEvent*);

    sipVH_QtWidgets_17(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDialog::paintEvent(::QPaintEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[20], &sipPySelf, SIP_NULLPTR, sipName_paintEvent);

    if (!sipMeth)
    {
        ::QInputDialog::paintEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintEvent*);

    sipVH_QtWidgets_16(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDialog::leaveEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[21], &sipPySelf, SIP_NULLPTR, sipName_leaveEvent);

    if (!sipMeth)
    {
        ::QInputDialog::leaveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDialog::enterEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[22], &sipPySelf, SIP_NULLPTR, sipName_enterEvent);

    if (!sipMeth)
    {
        ::QInputDialog::enterEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDialog::focusOutEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, SIP_NULLPTR, sipName_focusOutEvent);

    if (!sipMeth)
    {
        ::QInputDialog::focusOutEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDialog::focusInEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_focusInEvent);

    if (!sipMeth)
    {
        ::QInputDialog::focusInEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDialog::keyReleaseEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[25], &sipPySelf, SIP_NULLPTR, sipName_keyReleaseEvent);

    if (!sipMeth)
    {
        ::QInputDialog::keyReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtWidgets_14(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDialog::keyPressEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[26], &sipPySelf, SIP_NULLPTR, sipName_keyPressEvent);

    if (!sipMeth)
    {
        ::QInputDialog::keyPressEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtWidgets_14(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDialog::wheelEvent(::QWheelEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[27], &sipPySelf, SIP_NULLPTR, sipName_wheelEvent);

    if (!sipMeth)
    {
        ::QInputDialog::wheelEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWheelEvent*);

    sipVH_QtWidgets_13(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDialog::mouseMoveEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[28], &sipPySelf, SIP_NULLPTR, sipName_mouseMoveEvent);

    if (!sipMeth)
    {
        ::QInputDialog::mouseMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDialog::mouseDoubleClickEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[29], &sipPySelf, SIP_NULLPTR, sipName_mouseDoubleClickEvent);

    if (!sipMeth)
    {
        ::QInputDialog::mouseDoubleClickEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDialog::mouseReleaseEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[30], &sipPySelf, SIP_NULLPTR, sipName_mouseReleaseEvent);

    if (!sipMeth)
    {
        ::QInputDialog::mouseReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDialog::mousePressEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[31], &sipPySelf, SIP_NULLPTR, sipName_mousePressEvent);

    if (!sipMeth)
    {
        ::QInputDialog::mousePressEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQInputDialog::heightForWidth(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[32]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_heightForWidth);

    if (!sipMeth)
        return ::QInputDialog::heightForWidth(a0);

    extern int sipVH_QtWidgets_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtWidgets_11(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QSize sipQInputDialog::minimumSizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[33]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_minimumSizeHint);

    if (!sipMeth)
        return ::QInputDialog::minimumSizeHint();

    extern ::QSize sipVH_QtWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QSize sipQInputDialog::sizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[34]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sizeHint);

    if (!sipMeth)
        return ::QInputDialog::sizeHint();

    extern ::QSize sipVH_QtWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQInputDialog::setVisible(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[35], &sipPySelf, SIP_NULLPTR, sipName_setVisible);

    if (!sipMeth)
    {
        ::QInputDialog::setVisible(a0);
        return;
    }

    extern void sipVH_QtWidgets_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    sipVH_QtWidgets_9(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQInputDialog::devType() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[36]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_devType);

    if (!sipMeth)
        return ::QInputDialog::devType();

    extern int sipVH_QtWidgets_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_8(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QPaintEngine* sipQInputDialog::paintEngine() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[37]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_paintEngine);

    if (!sipMeth)
        return ::QInputDialog::paintEngine();

    extern ::QPaintEngine* sipVH_QtWidgets_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_7(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQInputDialog::metric(::QPaintDevice::PaintDeviceMetric a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[38]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_metric);

    if (!sipMeth)
        return ::QInputDialog::metric(a0);

    extern int sipVH_QtWidgets_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintDevice::PaintDeviceMetric);

    return sipVH_QtWidgets_6(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQInputDialog::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[39], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QInputDialog::event(a0);

    extern bool sipVH_QtWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQInputDialog::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[40], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QInputDialog::eventFilter(a0, a1);

    extern bool sipVH_QtWidgets_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtWidgets_4(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQInputDialog::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[41], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QInputDialog::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtWidgets_3(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDialog::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[42], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QInputDialog::childEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtWidgets_2(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDialog::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[43], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QInputDialog::customEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDialog::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[44], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QInputDialog::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDialog::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[45], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QInputDialog::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQInputDialog::exec()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[46], &sipPySelf, SIP_NULLPTR, sipName_exec_);

    if (!sipMeth)
        return ::QInputDialog::exec();

    extern int sipVH_QtWidgets_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_8(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQInputDialog::done(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[47], &sipPySelf, SIP_NULLPTR, sipName_done);

    if (!sipMeth)
    {
        ::QInputDialog::done(a0);
        return;
    }

    extern void sipVH_QtWidgets_59(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtWidgets_59(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDialog::accept()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[48], &sipPySelf, SIP_NULLPTR, sipName_accept);

    if (!sipMeth)
    {
        ::QInputDialog::accept();
        return;
    }

    extern void sipVH_QtWidgets_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtWidgets_37(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQInputDialog::reject()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[49], &sipPySelf, SIP_NULLPTR, sipName_reject);

    if (!sipMeth)
    {
        ::QInputDialog::reject();
        return;
    }

    extern void sipVH_QtWidgets_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtWidgets_37(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQInputDialog::open()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[50], &sipPySelf, SIP_NULLPTR, sipName_open);

    if (!sipMeth)
    {
        ::QInputDialog::open();
        return;
    }

    extern void sipVH_QtWidgets_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtWidgets_37(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}


PyDoc_STRVAR(doc_QInputDialog_getText, "getText(parent: Optional[QWidget], title: Optional[str], label: Optional[str], echo: QLineEdit.EchoMode = QLineEdit.Normal, text: Optional[str] = '', flags: Union[Qt.WindowFlags, Qt.WindowType] = Qt.WindowFlags(), inputMethodHints: Union[Qt.InputMethodHints, Qt.InputMethodHint] = Qt.ImhNone) -> (str, Optional[bool])");

extern "C" {static PyObject *meth_QInputDialog_getText(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_getText(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWidget* a0;
        const ::QString* a1;
        int a1State = 0;
        const ::QString* a2;
        int a2State = 0;
        ::QLineEdit::EchoMode a3 = QLineEdit::Normal;
        const ::QString& a4def = QString();
        const ::QString* a4 = &a4def;
        int a4State = 0;
        bool a5;
        ::Qt::WindowFlags a6def = Qt::WindowFlags();
        ::Qt::WindowFlags* a6 = &a6def;
        int a6State = 0;
        ::Qt::InputMethodHints a7def = Qt::ImhNone;
        ::Qt::InputMethodHints* a7 = &a7def;
        int a7State = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_echo,
            sipName_text,
            sipName_flags,
            sipName_inputMethodHints,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8J1J1|EJ1J1J1", sipType_QWidget, &a0, sipType_QString, &a1, &a1State, sipType_QString, &a2, &a2State, sipType_QLineEdit_EchoMode, &a3, sipType_QString, &a4, &a4State, sipType_Qt_WindowFlags, &a6, &a6State, sipType_Qt_InputMethodHints, &a7, &a7State))
        {
            ::QString*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = new ::QString(::QInputDialog::getText(a0, *a1, *a2, a3, *a4, &a5, *a6, *a7));
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);
            sipReleaseType(const_cast< ::QString *>(a4), sipType_QString, a4State);
            sipReleaseType(a6, sipType_Qt_WindowFlags, a6State);
            sipReleaseType(a7, sipType_Qt_InputMethodHints, a7State);

            PyObject *sipResObj = sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
            return sipBuildResult(0, "(Rb)", sipResObj, a5);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_getText, doc_QInputDialog_getText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_getInt, "getInt(parent: Optional[QWidget], title: Optional[str], label: Optional[str], value: int = 0, min: int = -2147483647, max: int = 2147483647, step: int = 1, flags: Union[Qt.WindowFlags, Qt.WindowType] = Qt.WindowFlags()) -> (int, Optional[bool])");

extern "C" {static PyObject *meth_QInputDialog_getInt(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_getInt(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWidget* a0;
        const ::QString* a1;
        int a1State = 0;
        const ::QString* a2;
        int a2State = 0;
        int a3 = 0;
        int a4 = -2147483647;
        int a5 = 2147483647;
        int a6 = 1;
        bool a7;
        ::Qt::WindowFlags a8def = Qt::WindowFlags();
        ::Qt::WindowFlags* a8 = &a8def;
        int a8State = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_value,
            sipName_min,
            sipName_max,
            sipName_step,
            sipName_flags,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8J1J1|iiiiJ1", sipType_QWidget, &a0, sipType_QString, &a1, &a1State, sipType_QString, &a2, &a2State, &a3, &a4, &a5, &a6, sipType_Qt_WindowFlags, &a8, &a8State))
        {
            int sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = ::QInputDialog::getInt(a0, *a1, *a2, a3, a4, a5, a6, &a7, *a8);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);
            sipReleaseType(a8, sipType_Qt_WindowFlags, a8State);

            return sipBuildResult(0, "(ib)", sipRes, a7);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_getInt, doc_QInputDialog_getInt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_getDouble, "getDouble(parent: Optional[QWidget], title: Optional[str], label: Optional[str], value: float = 0, min: float = -2147483647, max: float = 2147483647, decimals: int = 1, flags: Union[Qt.WindowFlags, Qt.WindowType] = Qt.WindowFlags()) -> (float, Optional[bool])\n"
"getDouble(parent: Optional[QWidget], title: Optional[str], label: Optional[str], value: float, minValue: float, maxValue: float, decimals: int, flags: Union[Qt.WindowFlags, Qt.WindowType], step: float) -> (float, Optional[bool])");

extern "C" {static PyObject *meth_QInputDialog_getDouble(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_getDouble(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWidget* a0;
        const ::QString* a1;
        int a1State = 0;
        const ::QString* a2;
        int a2State = 0;
        double a3 = 0;
        double a4 = -2147483647;
        double a5 = 2147483647;
        int a6 = 1;
        bool a7;
        ::Qt::WindowFlags a8def = Qt::WindowFlags();
        ::Qt::WindowFlags* a8 = &a8def;
        int a8State = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_value,
            sipName_min,
            sipName_max,
            sipName_decimals,
            sipName_flags,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8J1J1|dddiJ1", sipType_QWidget, &a0, sipType_QString, &a1, &a1State, sipType_QString, &a2, &a2State, &a3, &a4, &a5, &a6, sipType_Qt_WindowFlags, &a8, &a8State))
        {
            double sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = ::QInputDialog::getDouble(a0, *a1, *a2, a3, a4, a5, a6, &a7, *a8);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);
            sipReleaseType(a8, sipType_Qt_WindowFlags, a8State);

            return sipBuildResult(0, "(db)", sipRes, a7);
        }
    }

    {
        ::QWidget* a0;
        const ::QString* a1;
        int a1State = 0;
        const ::QString* a2;
        int a2State = 0;
        double a3;
        double a4;
        double a5;
        int a6;
        bool a7;
        ::Qt::WindowFlags* a8;
        int a8State = 0;
        double a9;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "J8J1J1dddiJ1d", sipType_QWidget, &a0, sipType_QString, &a1, &a1State, sipType_QString, &a2, &a2State, &a3, &a4, &a5, &a6, sipType_Qt_WindowFlags, &a8, &a8State, &a9))
        {
            double sipRes;

            sipRes = ::QInputDialog::getDouble(a0, *a1, *a2, a3, a4, a5, a6, &a7, *a8, a9);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);
            sipReleaseType(a8, sipType_Qt_WindowFlags, a8State);

            return sipBuildResult(0, "(db)", sipRes, a7);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_getDouble, doc_QInputDialog_getDouble);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_getItem, "getItem(parent: Optional[QWidget], title: Optional[str], label: Optional[str], items: Iterable[Optional[str]], current: int = 0, editable: bool = True, flags: Union[Qt.WindowFlags, Qt.WindowType] = Qt.WindowFlags(), inputMethodHints: Union[Qt.InputMethodHints, Qt.InputMethodHint] = Qt.ImhNone) -> (str, Optional[bool])");

extern "C" {static PyObject *meth_QInputDialog_getItem(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_getItem(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWidget* a0;
        const ::QString* a1;
        int a1State = 0;
        const ::QString* a2;
        int a2State = 0;
        const ::QStringList* a3;
        int a3State = 0;
        int a4 = 0;
        bool a5 = 1;
        bool a6;
        ::Qt::WindowFlags a7def = Qt::WindowFlags();
        ::Qt::WindowFlags* a7 = &a7def;
        int a7State = 0;
        ::Qt::InputMethodHints a8def = Qt::ImhNone;
        ::Qt::InputMethodHints* a8 = &a8def;
        int a8State = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_current,
            sipName_editable,
            sipName_flags,
            sipName_inputMethodHints,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8J1J1J1|ibJ1J1", sipType_QWidget, &a0, sipType_QString, &a1, &a1State, sipType_QString, &a2, &a2State, sipType_QStringList, &a3, &a3State, &a4, &a5, sipType_Qt_WindowFlags, &a7, &a7State, sipType_Qt_InputMethodHints, &a8, &a8State))
        {
            ::QString*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = new ::QString(::QInputDialog::getItem(a0, *a1, *a2, *a3, a4, a5, &a6, *a7, *a8));
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);
            sipReleaseType(const_cast< ::QStringList *>(a3), sipType_QStringList, a3State);
            sipReleaseType(a7, sipType_Qt_WindowFlags, a7State);
            sipReleaseType(a8, sipType_Qt_InputMethodHints, a8State);

            PyObject *sipResObj = sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
            return sipBuildResult(0, "(Rb)", sipResObj, a6);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_getItem, doc_QInputDialog_getItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_getMultiLineText, "getMultiLineText(parent: Optional[QWidget], title: Optional[str], label: Optional[str], text: Optional[str] = '', flags: Union[Qt.WindowFlags, Qt.WindowType] = Qt.WindowFlags(), inputMethodHints: Union[Qt.InputMethodHints, Qt.InputMethodHint] = Qt.ImhNone) -> (str, Optional[bool])");

extern "C" {static PyObject *meth_QInputDialog_getMultiLineText(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_getMultiLineText(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWidget* a0;
        const ::QString* a1;
        int a1State = 0;
        const ::QString* a2;
        int a2State = 0;
        const ::QString& a3def = QString();
        const ::QString* a3 = &a3def;
        int a3State = 0;
        bool a4;
        ::Qt::WindowFlags a5def = Qt::WindowFlags();
        ::Qt::WindowFlags* a5 = &a5def;
        int a5State = 0;
        ::Qt::InputMethodHints a6def = Qt::ImhNone;
        ::Qt::InputMethodHints* a6 = &a6def;
        int a6State = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_text,
            sipName_flags,
            sipName_inputMethodHints,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8J1J1|J1J1J1", sipType_QWidget, &a0, sipType_QString, &a1, &a1State, sipType_QString, &a2, &a2State, sipType_QString, &a3, &a3State, sipType_Qt_WindowFlags, &a5, &a5State, sipType_Qt_InputMethodHints, &a6, &a6State))
        {
            ::QString*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = new ::QString(::QInputDialog::getMultiLineText(a0, *a1, *a2, *a3, &a4, *a5, *a6));
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);
            sipReleaseType(const_cast< ::QString *>(a3), sipType_QString, a3State);
            sipReleaseType(a5, sipType_Qt_WindowFlags, a5State);
            sipReleaseType(a6, sipType_Qt_InputMethodHints, a6State);

            PyObject *sipResObj = sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
            return sipBuildResult(0, "(Rb)", sipResObj, a4);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_getMultiLineText, doc_QInputDialog_getMultiLineText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_setInputMode, "setInputMode(self, mode: QInputDialog.InputMode)");

extern "C" {static PyObject *meth_QInputDialog_setInputMode(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_setInputMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QInputDialog::InputMode a0;
        ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QInputDialog, &sipCpp, sipType_QInputDialog_InputMode, &a0))
        {
            sipCpp->setInputMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_setInputMode, doc_QInputDialog_setInputMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_inputMode, "inputMode(self) -> QInputDialog.InputMode");

extern "C" {static PyObject *meth_QInputDialog_inputMode(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_inputMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QInputDialog, &sipCpp))
        {
            ::QInputDialog::InputMode sipRes;

            sipRes = sipCpp->inputMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QInputDialog_InputMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_inputMode, doc_QInputDialog_inputMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_setLabelText, "setLabelText(self, text: Optional[str])");

extern "C" {static PyObject *meth_QInputDialog_setLabelText(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_setLabelText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QInputDialog, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setLabelText(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_setLabelText, doc_QInputDialog_setLabelText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_labelText, "labelText(self) -> str");

extern "C" {static PyObject *meth_QInputDialog_labelText(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_labelText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QInputDialog, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->labelText());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_labelText, doc_QInputDialog_labelText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_setOption, "setOption(self, option: QInputDialog.InputDialogOption, on: bool = True)");

extern "C" {static PyObject *meth_QInputDialog_setOption(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_setOption(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QInputDialog::InputDialogOption a0;
        bool a1 = 1;
        ::QInputDialog *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_on,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BE|b", &sipSelf, sipType_QInputDialog, &sipCpp, sipType_QInputDialog_InputDialogOption, &a0, &a1))
        {
            sipCpp->setOption(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_setOption, doc_QInputDialog_setOption);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_testOption, "testOption(self, option: QInputDialog.InputDialogOption) -> bool");

extern "C" {static PyObject *meth_QInputDialog_testOption(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_testOption(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QInputDialog::InputDialogOption a0;
        const ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QInputDialog, &sipCpp, sipType_QInputDialog_InputDialogOption, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->testOption(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_testOption, doc_QInputDialog_testOption);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_setOptions, "setOptions(self, options: Union[QInputDialog.InputDialogOptions, QInputDialog.InputDialogOption])");

extern "C" {static PyObject *meth_QInputDialog_setOptions(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_setOptions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QInputDialog::InputDialogOptions* a0;
        int a0State = 0;
        ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QInputDialog, &sipCpp, sipType_QInputDialog_InputDialogOptions, &a0, &a0State))
        {
            sipCpp->setOptions(*a0);
            sipReleaseType(a0, sipType_QInputDialog_InputDialogOptions, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_setOptions, doc_QInputDialog_setOptions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_options, "options(self) -> QInputDialog.InputDialogOptions");

extern "C" {static PyObject *meth_QInputDialog_options(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_options(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QInputDialog, &sipCpp))
        {
            ::QInputDialog::InputDialogOptions*sipRes;

            sipRes = new ::QInputDialog::InputDialogOptions(sipCpp->options());

            return sipConvertFromNewType(sipRes, sipType_QInputDialog_InputDialogOptions, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_options, doc_QInputDialog_options);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_setTextValue, "setTextValue(self, text: Optional[str])");

extern "C" {static PyObject *meth_QInputDialog_setTextValue(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_setTextValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QInputDialog, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setTextValue(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_setTextValue, doc_QInputDialog_setTextValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_textValue, "textValue(self) -> str");

extern "C" {static PyObject *meth_QInputDialog_textValue(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_textValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QInputDialog, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->textValue());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_textValue, doc_QInputDialog_textValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_setTextEchoMode, "setTextEchoMode(self, mode: QLineEdit.EchoMode)");

extern "C" {static PyObject *meth_QInputDialog_setTextEchoMode(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_setTextEchoMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLineEdit::EchoMode a0;
        ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QInputDialog, &sipCpp, sipType_QLineEdit_EchoMode, &a0))
        {
            sipCpp->setTextEchoMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_setTextEchoMode, doc_QInputDialog_setTextEchoMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_textEchoMode, "textEchoMode(self) -> QLineEdit.EchoMode");

extern "C" {static PyObject *meth_QInputDialog_textEchoMode(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_textEchoMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QInputDialog, &sipCpp))
        {
            ::QLineEdit::EchoMode sipRes;

            sipRes = sipCpp->textEchoMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QLineEdit_EchoMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_textEchoMode, doc_QInputDialog_textEchoMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_setComboBoxEditable, "setComboBoxEditable(self, editable: bool)");

extern "C" {static PyObject *meth_QInputDialog_setComboBoxEditable(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_setComboBoxEditable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QInputDialog, &sipCpp, &a0))
        {
            sipCpp->setComboBoxEditable(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_setComboBoxEditable, doc_QInputDialog_setComboBoxEditable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_isComboBoxEditable, "isComboBoxEditable(self) -> bool");

extern "C" {static PyObject *meth_QInputDialog_isComboBoxEditable(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_isComboBoxEditable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QInputDialog, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isComboBoxEditable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_isComboBoxEditable, doc_QInputDialog_isComboBoxEditable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_setComboBoxItems, "setComboBoxItems(self, items: Iterable[Optional[str]])");

extern "C" {static PyObject *meth_QInputDialog_setComboBoxItems(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_setComboBoxItems(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStringList* a0;
        int a0State = 0;
        ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QInputDialog, &sipCpp, sipType_QStringList, &a0, &a0State))
        {
            sipCpp->setComboBoxItems(*a0);
            sipReleaseType(const_cast< ::QStringList *>(a0), sipType_QStringList, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_setComboBoxItems, doc_QInputDialog_setComboBoxItems);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_comboBoxItems, "comboBoxItems(self) -> list[str]");

extern "C" {static PyObject *meth_QInputDialog_comboBoxItems(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_comboBoxItems(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QInputDialog, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->comboBoxItems());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_comboBoxItems, doc_QInputDialog_comboBoxItems);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_setIntValue, "setIntValue(self, value: int)");

extern "C" {static PyObject *meth_QInputDialog_setIntValue(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_setIntValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QInputDialog, &sipCpp, &a0))
        {
            sipCpp->setIntValue(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_setIntValue, doc_QInputDialog_setIntValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_intValue, "intValue(self) -> int");

extern "C" {static PyObject *meth_QInputDialog_intValue(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_intValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QInputDialog, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->intValue();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_intValue, doc_QInputDialog_intValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_setIntMinimum, "setIntMinimum(self, min: int)");

extern "C" {static PyObject *meth_QInputDialog_setIntMinimum(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_setIntMinimum(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QInputDialog, &sipCpp, &a0))
        {
            sipCpp->setIntMinimum(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_setIntMinimum, doc_QInputDialog_setIntMinimum);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_intMinimum, "intMinimum(self) -> int");

extern "C" {static PyObject *meth_QInputDialog_intMinimum(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_intMinimum(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QInputDialog, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->intMinimum();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_intMinimum, doc_QInputDialog_intMinimum);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_setIntMaximum, "setIntMaximum(self, max: int)");

extern "C" {static PyObject *meth_QInputDialog_setIntMaximum(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_setIntMaximum(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QInputDialog, &sipCpp, &a0))
        {
            sipCpp->setIntMaximum(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_setIntMaximum, doc_QInputDialog_setIntMaximum);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_intMaximum, "intMaximum(self) -> int");

extern "C" {static PyObject *meth_QInputDialog_intMaximum(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_intMaximum(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QInputDialog, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->intMaximum();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_intMaximum, doc_QInputDialog_intMaximum);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_setIntRange, "setIntRange(self, min: int, max: int)");

extern "C" {static PyObject *meth_QInputDialog_setIntRange(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_setIntRange(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QInputDialog, &sipCpp, &a0, &a1))
        {
            sipCpp->setIntRange(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_setIntRange, doc_QInputDialog_setIntRange);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_setIntStep, "setIntStep(self, step: int)");

extern "C" {static PyObject *meth_QInputDialog_setIntStep(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_setIntStep(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QInputDialog, &sipCpp, &a0))
        {
            sipCpp->setIntStep(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_setIntStep, doc_QInputDialog_setIntStep);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_intStep, "intStep(self) -> int");

extern "C" {static PyObject *meth_QInputDialog_intStep(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_intStep(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QInputDialog, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->intStep();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_intStep, doc_QInputDialog_intStep);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_setDoubleValue, "setDoubleValue(self, value: float)");

extern "C" {static PyObject *meth_QInputDialog_setDoubleValue(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_setDoubleValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        double a0;
        ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QInputDialog, &sipCpp, &a0))
        {
            sipCpp->setDoubleValue(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_setDoubleValue, doc_QInputDialog_setDoubleValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_doubleValue, "doubleValue(self) -> float");

extern "C" {static PyObject *meth_QInputDialog_doubleValue(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_doubleValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QInputDialog, &sipCpp))
        {
            double sipRes;

            sipRes = sipCpp->doubleValue();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_doubleValue, doc_QInputDialog_doubleValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_setDoubleMinimum, "setDoubleMinimum(self, min: float)");

extern "C" {static PyObject *meth_QInputDialog_setDoubleMinimum(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_setDoubleMinimum(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        double a0;
        ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QInputDialog, &sipCpp, &a0))
        {
            sipCpp->setDoubleMinimum(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_setDoubleMinimum, doc_QInputDialog_setDoubleMinimum);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_doubleMinimum, "doubleMinimum(self) -> float");

extern "C" {static PyObject *meth_QInputDialog_doubleMinimum(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_doubleMinimum(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QInputDialog, &sipCpp))
        {
            double sipRes;

            sipRes = sipCpp->doubleMinimum();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_doubleMinimum, doc_QInputDialog_doubleMinimum);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_setDoubleMaximum, "setDoubleMaximum(self, max: float)");

extern "C" {static PyObject *meth_QInputDialog_setDoubleMaximum(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_setDoubleMaximum(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        double a0;
        ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QInputDialog, &sipCpp, &a0))
        {
            sipCpp->setDoubleMaximum(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_setDoubleMaximum, doc_QInputDialog_setDoubleMaximum);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_doubleMaximum, "doubleMaximum(self) -> float");

extern "C" {static PyObject *meth_QInputDialog_doubleMaximum(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_doubleMaximum(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QInputDialog, &sipCpp))
        {
            double sipRes;

            sipRes = sipCpp->doubleMaximum();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_doubleMaximum, doc_QInputDialog_doubleMaximum);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_setDoubleRange, "setDoubleRange(self, min: float, max: float)");

extern "C" {static PyObject *meth_QInputDialog_setDoubleRange(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_setDoubleRange(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        double a0;
        double a1;
        ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdd", &sipSelf, sipType_QInputDialog, &sipCpp, &a0, &a1))
        {
            sipCpp->setDoubleRange(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_setDoubleRange, doc_QInputDialog_setDoubleRange);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_setDoubleDecimals, "setDoubleDecimals(self, decimals: int)");

extern "C" {static PyObject *meth_QInputDialog_setDoubleDecimals(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_setDoubleDecimals(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QInputDialog, &sipCpp, &a0))
        {
            sipCpp->setDoubleDecimals(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_setDoubleDecimals, doc_QInputDialog_setDoubleDecimals);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_doubleDecimals, "doubleDecimals(self) -> int");

extern "C" {static PyObject *meth_QInputDialog_doubleDecimals(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_doubleDecimals(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QInputDialog, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->doubleDecimals();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_doubleDecimals, doc_QInputDialog_doubleDecimals);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_setOkButtonText, "setOkButtonText(self, text: Optional[str])");

extern "C" {static PyObject *meth_QInputDialog_setOkButtonText(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_setOkButtonText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QInputDialog, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setOkButtonText(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_setOkButtonText, doc_QInputDialog_setOkButtonText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_okButtonText, "okButtonText(self) -> str");

extern "C" {static PyObject *meth_QInputDialog_okButtonText(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_okButtonText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QInputDialog, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->okButtonText());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_okButtonText, doc_QInputDialog_okButtonText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_setCancelButtonText, "setCancelButtonText(self, text: Optional[str])");

extern "C" {static PyObject *meth_QInputDialog_setCancelButtonText(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_setCancelButtonText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QInputDialog, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setCancelButtonText(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_setCancelButtonText, doc_QInputDialog_setCancelButtonText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_cancelButtonText, "cancelButtonText(self) -> str");

extern "C" {static PyObject *meth_QInputDialog_cancelButtonText(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_cancelButtonText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QInputDialog, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->cancelButtonText());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_cancelButtonText, doc_QInputDialog_cancelButtonText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_open, "open(self)\n"
"open(self, slot: PYQT_SLOT)");

extern "C" {static PyObject *meth_QInputDialog_open(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_open(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QInputDialog, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp->::QInputDialog::open() : sipCpp->open());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        PyObject * a0;
        ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QInputDialog, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 101 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qinputdialog.sip"
        QObject *receiver;
        QByteArray slot_signature;
        
        if ((sipError = pyqt5_qtwidgets_get_connection_parts(a0, sipCpp, "()", false, &receiver, slot_signature)) == sipErrorNone)
        {
            sipCpp->open(receiver, slot_signature.constData());
        }
        else if (sipError == sipErrorContinue)
        {
            sipError = sipBadCallableArg(0, a0);
        }
#line 2607 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQInputDialog.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_open, doc_QInputDialog_open);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_minimumSizeHint, "minimumSizeHint(self) -> QSize");

extern "C" {static PyObject *meth_QInputDialog_minimumSizeHint(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_minimumSizeHint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QInputDialog, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize((sipSelfWasArg ? sipCpp->::QInputDialog::minimumSizeHint() : sipCpp->minimumSizeHint()));

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_minimumSizeHint, doc_QInputDialog_minimumSizeHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_sizeHint, "sizeHint(self) -> QSize");

extern "C" {static PyObject *meth_QInputDialog_sizeHint(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_sizeHint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QInputDialog, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize((sipSelfWasArg ? sipCpp->::QInputDialog::sizeHint() : sipCpp->sizeHint()));

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_sizeHint, doc_QInputDialog_sizeHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_setVisible, "setVisible(self, visible: bool)");

extern "C" {static PyObject *meth_QInputDialog_setVisible(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_setVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        bool a0;
        ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QInputDialog, &sipCpp, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QInputDialog::setVisible(a0) : sipCpp->setVisible(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_setVisible, doc_QInputDialog_setVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_done, "done(self, result: int)");

extern "C" {static PyObject *meth_QInputDialog_done(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_done(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QInputDialog, &sipCpp, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QInputDialog::done(a0) : sipCpp->done(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_done, doc_QInputDialog_done);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_setDoubleStep, "setDoubleStep(self, step: float)");

extern "C" {static PyObject *meth_QInputDialog_setDoubleStep(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_setDoubleStep(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        double a0;
        ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QInputDialog, &sipCpp, &a0))
        {
            sipCpp->setDoubleStep(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_setDoubleStep, doc_QInputDialog_setDoubleStep);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDialog_doubleStep, "doubleStep(self) -> float");

extern "C" {static PyObject *meth_QInputDialog_doubleStep(PyObject *, PyObject *);}
static PyObject *meth_QInputDialog_doubleStep(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QInputDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QInputDialog, &sipCpp))
        {
            double sipRes;

            sipRes = sipCpp->doubleStep();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDialog, sipName_doubleStep, doc_QInputDialog_doubleStep);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QInputDialog(void *, const sipTypeDef *);}
static void *cast_QInputDialog(void *sipCppV, const sipTypeDef *targetType)
{
    ::QInputDialog *sipCpp = reinterpret_cast< ::QInputDialog *>(sipCppV);

    if (targetType == sipType_QInputDialog)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QDialog)->ctd_cast(static_cast< ::QDialog *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QInputDialog(void *, int);}
static void release_QInputDialog(void *sipCppV, int)
{
    ::QInputDialog *sipCpp = reinterpret_cast< ::QInputDialog *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QInputDialog(Py_ssize_t);}
static void *array_QInputDialog(Py_ssize_t sipNrElem)
{
    return new ::QInputDialog[sipNrElem];
}


extern "C" {static void array_delete_QInputDialog(void *);}
static void array_delete_QInputDialog(void *sipCpp)
{
    delete[] reinterpret_cast< ::QInputDialog *>(sipCpp);
}


extern "C" {static void dealloc_QInputDialog(sipSimpleWrapper *);}
static void dealloc_QInputDialog(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQInputDialog *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QInputDialog(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QInputDialog(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QInputDialog(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQInputDialog *sipCpp = SIP_NULLPTR;

    {
        ::QWidget* a0 = 0;
        ::Qt::WindowFlags a1def = Qt::WindowFlags();
        ::Qt::WindowFlags* a1 = &a1def;
        int a1State = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
            sipName_flags,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JHJ1", sipType_QWidget, &a0, sipOwner, sipType_Qt_WindowFlags, &a1, &a1State))
        {
            sipCpp = new sipQInputDialog(a0, *a1);
            sipReleaseType(a1, sipType_Qt_WindowFlags, a1State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QInputDialog[] = {{62, 255, 1}};


static PyMethodDef methods_QInputDialog[] = {
    {sipName_cancelButtonText, meth_QInputDialog_cancelButtonText, METH_VARARGS, doc_QInputDialog_cancelButtonText},
    {sipName_comboBoxItems, meth_QInputDialog_comboBoxItems, METH_VARARGS, doc_QInputDialog_comboBoxItems},
    {sipName_done, meth_QInputDialog_done, METH_VARARGS, doc_QInputDialog_done},
    {sipName_doubleDecimals, meth_QInputDialog_doubleDecimals, METH_VARARGS, doc_QInputDialog_doubleDecimals},
    {sipName_doubleMaximum, meth_QInputDialog_doubleMaximum, METH_VARARGS, doc_QInputDialog_doubleMaximum},
    {sipName_doubleMinimum, meth_QInputDialog_doubleMinimum, METH_VARARGS, doc_QInputDialog_doubleMinimum},
    {sipName_doubleStep, meth_QInputDialog_doubleStep, METH_VARARGS, doc_QInputDialog_doubleStep},
    {sipName_doubleValue, meth_QInputDialog_doubleValue, METH_VARARGS, doc_QInputDialog_doubleValue},
    {sipName_getDouble, SIP_MLMETH_CAST(meth_QInputDialog_getDouble), METH_VARARGS|METH_KEYWORDS, doc_QInputDialog_getDouble},
    {sipName_getInt, SIP_MLMETH_CAST(meth_QInputDialog_getInt), METH_VARARGS|METH_KEYWORDS, doc_QInputDialog_getInt},
    {sipName_getItem, SIP_MLMETH_CAST(meth_QInputDialog_getItem), METH_VARARGS|METH_KEYWORDS, doc_QInputDialog_getItem},
    {sipName_getMultiLineText, SIP_MLMETH_CAST(meth_QInputDialog_getMultiLineText), METH_VARARGS|METH_KEYWORDS, doc_QInputDialog_getMultiLineText},
    {sipName_getText, SIP_MLMETH_CAST(meth_QInputDialog_getText), METH_VARARGS|METH_KEYWORDS, doc_QInputDialog_getText},
    {sipName_inputMode, meth_QInputDialog_inputMode, METH_VARARGS, doc_QInputDialog_inputMode},
    {sipName_intMaximum, meth_QInputDialog_intMaximum, METH_VARARGS, doc_QInputDialog_intMaximum},
    {sipName_intMinimum, meth_QInputDialog_intMinimum, METH_VARARGS, doc_QInputDialog_intMinimum},
    {sipName_intStep, meth_QInputDialog_intStep, METH_VARARGS, doc_QInputDialog_intStep},
    {sipName_intValue, meth_QInputDialog_intValue, METH_VARARGS, doc_QInputDialog_intValue},
    {sipName_isComboBoxEditable, meth_QInputDialog_isComboBoxEditable, METH_VARARGS, doc_QInputDialog_isComboBoxEditable},
    {sipName_labelText, meth_QInputDialog_labelText, METH_VARARGS, doc_QInputDialog_labelText},
    {sipName_minimumSizeHint, meth_QInputDialog_minimumSizeHint, METH_VARARGS, doc_QInputDialog_minimumSizeHint},
    {sipName_okButtonText, meth_QInputDialog_okButtonText, METH_VARARGS, doc_QInputDialog_okButtonText},
    {sipName_open, meth_QInputDialog_open, METH_VARARGS, doc_QInputDialog_open},
    {sipName_options, meth_QInputDialog_options, METH_VARARGS, doc_QInputDialog_options},
    {sipName_setCancelButtonText, meth_QInputDialog_setCancelButtonText, METH_VARARGS, doc_QInputDialog_setCancelButtonText},
    {sipName_setComboBoxEditable, meth_QInputDialog_setComboBoxEditable, METH_VARARGS, doc_QInputDialog_setComboBoxEditable},
    {sipName_setComboBoxItems, meth_QInputDialog_setComboBoxItems, METH_VARARGS, doc_QInputDialog_setComboBoxItems},
    {sipName_setDoubleDecimals, meth_QInputDialog_setDoubleDecimals, METH_VARARGS, doc_QInputDialog_setDoubleDecimals},
    {sipName_setDoubleMaximum, meth_QInputDialog_setDoubleMaximum, METH_VARARGS, doc_QInputDialog_setDoubleMaximum},
    {sipName_setDoubleMinimum, meth_QInputDialog_setDoubleMinimum, METH_VARARGS, doc_QInputDialog_setDoubleMinimum},
    {sipName_setDoubleRange, meth_QInputDialog_setDoubleRange, METH_VARARGS, doc_QInputDialog_setDoubleRange},
    {sipName_setDoubleStep, meth_QInputDialog_setDoubleStep, METH_VARARGS, doc_QInputDialog_setDoubleStep},
    {sipName_setDoubleValue, meth_QInputDialog_setDoubleValue, METH_VARARGS, doc_QInputDialog_setDoubleValue},
    {sipName_setInputMode, meth_QInputDialog_setInputMode, METH_VARARGS, doc_QInputDialog_setInputMode},
    {sipName_setIntMaximum, meth_QInputDialog_setIntMaximum, METH_VARARGS, doc_QInputDialog_setIntMaximum},
    {sipName_setIntMinimum, meth_QInputDialog_setIntMinimum, METH_VARARGS, doc_QInputDialog_setIntMinimum},
    {sipName_setIntRange, meth_QInputDialog_setIntRange, METH_VARARGS, doc_QInputDialog_setIntRange},
    {sipName_setIntStep, meth_QInputDialog_setIntStep, METH_VARARGS, doc_QInputDialog_setIntStep},
    {sipName_setIntValue, meth_QInputDialog_setIntValue, METH_VARARGS, doc_QInputDialog_setIntValue},
    {sipName_setLabelText, meth_QInputDialog_setLabelText, METH_VARARGS, doc_QInputDialog_setLabelText},
    {sipName_setOkButtonText, meth_QInputDialog_setOkButtonText, METH_VARARGS, doc_QInputDialog_setOkButtonText},
    {sipName_setOption, SIP_MLMETH_CAST(meth_QInputDialog_setOption), METH_VARARGS|METH_KEYWORDS, doc_QInputDialog_setOption},
    {sipName_setOptions, meth_QInputDialog_setOptions, METH_VARARGS, doc_QInputDialog_setOptions},
    {sipName_setTextEchoMode, meth_QInputDialog_setTextEchoMode, METH_VARARGS, doc_QInputDialog_setTextEchoMode},
    {sipName_setTextValue, meth_QInputDialog_setTextValue, METH_VARARGS, doc_QInputDialog_setTextValue},
    {sipName_setVisible, meth_QInputDialog_setVisible, METH_VARARGS, doc_QInputDialog_setVisible},
    {sipName_sizeHint, meth_QInputDialog_sizeHint, METH_VARARGS, doc_QInputDialog_sizeHint},
    {sipName_testOption, meth_QInputDialog_testOption, METH_VARARGS, doc_QInputDialog_testOption},
    {sipName_textEchoMode, meth_QInputDialog_textEchoMode, METH_VARARGS, doc_QInputDialog_textEchoMode},
    {sipName_textValue, meth_QInputDialog_textValue, METH_VARARGS, doc_QInputDialog_textValue}
};

static sipEnumMemberDef enummembers_QInputDialog[] = {
    {sipName_DoubleInput, static_cast<int>(::QInputDialog::DoubleInput), 181},
    {sipName_IntInput, static_cast<int>(::QInputDialog::IntInput), 181},
    {sipName_NoButtons, static_cast<int>(::QInputDialog::NoButtons), 179},
    {sipName_TextInput, static_cast<int>(::QInputDialog::TextInput), 181},
    {sipName_UseListViewForComboBoxItems, static_cast<int>(::QInputDialog::UseListViewForComboBoxItems), 179},
    {sipName_UsePlainTextEditForTextInput, static_cast<int>(::QInputDialog::UsePlainTextEditForTextInput), 179},
};

PyDoc_STRVAR(doc_QInputDialog, "\1QInputDialog(parent: Optional[QWidget] = None, flags: Union[Qt.WindowFlags, Qt.WindowType] = Qt.WindowFlags())");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QInputDialog[] = {
    {"doubleValueSelected(double)", "\1doubleValueSelected(self, value: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"doubleValueChanged(double)", "\1doubleValueChanged(self, value: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"intValueSelected(int)", "\1intValueSelected(self, value: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"intValueChanged(int)", "\1intValueChanged(self, value: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"textValueSelected(QString)", "\1textValueSelected(self, text: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"textValueChanged(QString)", "\1textValueChanged(self, text: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QInputDialog = {
    &::QInputDialog::staticMetaObject,
    0,
    signals_QInputDialog,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWidgets_QInputDialog = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QInputDialog,
        SIP_NULLPTR,
        &plugin_QInputDialog,
    },
    {
        sipNameNr_QInputDialog,
        {0, 0, 1},
        50, methods_QInputDialog,
        6, enummembers_QInputDialog,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QInputDialog,
    -1,
    -1,
    supers_QInputDialog,
    SIP_NULLPTR,
    init_type_QInputDialog,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QInputDialog,
    SIP_NULLPTR,
    array_QInputDialog,
    SIP_NULLPTR,
    release_QInputDialog,
    cast_QInputDialog,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QInputDialog,
    sizeof (::QInputDialog),
};
